# PyCataloguer

PyCataloguer is universal cataloguer for your files. You can organize books, videos, music on your computer. You can copy files, database and source code on another computer and you need only replace some absolute paths in the database!

The programm has command line interface. To see more, run `pycat -h` after installing.

To install PyCataloguer, run command `pip3 install pycataloguer`

# Roadmap

- [x] files - adding, deleting, viewing.
- [X] files - editing general properties (updating)
- [x] paths, where PyCataloguer search the files - adding, deleting, viewing.
- [x] import/export sql dump of database
- [x] categories - adding, deliting, parenting (tree of categories)
- [x] categories - adding files to categories
- [ ] files - open via standart software (from search and from viewing properties)
- [x] files - scan directories and adding new files
- [ ] files - scan directories and search replaced files (by md5-hash)
- [ ] properties - adding, editing, adding to files

# Ideal Roadmap

- [ ] - adding file to the database, by selecting item from context menu of your favourite file manager (on Linux, Mac, Windows)
- [ ] - поиск по принципиальным электрическим схемам

I hope PyCataloguer will help you! :)